@@ -27,7 +27,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <glib/gstdio.h>
-#include <glib/gi18n.h>
 #include <config.h>
 
 #include "mcd-master.h"
@@ -78,6 +77,10 @@ _mcd_account_connection_begin (McdAccount *account,
     ctx->params = _mcd_account_dup_parameters (account);
     g_assert (ctx->params != NULL);
 
+    _mcd_account_set_connection_status (account,
+                                        TP_CONNECTION_STATUS_CONNECTING,
+                                        TP_CONNECTION_STATUS_REASON_REQUESTED,
+                                        NULL, NULL, NULL);
     _mcd_account_set_connection_context (account, ctx);
     mcd_account_connection_proceed (account, TRUE);
 }
