@@ -20,7 +20,11 @@
  */
 
 #include "config.h"
+
 #include <string.h>
+
+#include <telepathy-glib/telepathy-glib.h>
+
 #include "mcd-account-manager-default.h"
 #include "mcd-debug.h"
 
@@ -77,12 +81,14 @@ _delete_from_keyring (const McpAccountStorage *self,
     {
       /* flag the whole account as purged */
       gchar *removed = g_strdup (account);
-      g_hash_table_insert (amd->removed_accounts, removed, removed);
+      g_hash_table_replace (amd->removed_accounts, removed, removed);
+      g_key_file_remove_group (amd->secrets, removed, NULL);
     }
   else
     {
       /* remember to forget this one param */
       g_key_file_set_value (amd->removed, account, key, "");
+      g_key_file_remove_key (amd->secrets, account, key, NULL);
     }
 }
 
@@ -187,7 +193,7 @@ _keyring_commit (const McpAccountStorage *self,
     {
       gsize j;
       gsize k;
-      GStrv keys = g_key_file_get_keys (amd->secrets, accts[i], &k, NULL);
+      GStrv keys = g_key_file_get_keys (amd->removed, accts[i], &k, NULL);
 
       if (keys == NULL)
         k = 0;
@@ -195,15 +201,21 @@ _keyring_commit (const McpAccountStorage *self,
       for (j = 0; j < k; j++)
         {
           KeyringSetData *ksd = g_slice_new0 (KeyringSetData);
+          const gchar *key = keys[j];
+
+          /* for compatibility with old gnome keyring code we must strip  *
+           * the param- prefix from the name before saving to the keyring */
+          if (g_str_has_prefix (key, "param-"))
+            key += strlen ("param-");
 
           ksd->account = g_strdup (accts[i]);
-          ksd->name = g_strdup (keys[j]);
+          ksd->name = g_strdup (key);
           ksd->set = FALSE;
 
           gnome_keyring_delete_password (&keyring_schema,
               _keyring_set_cb, ksd, NULL,
               "account", accts[i],
-              "param", keys[j],
+              "param", key,
               NULL);
         }
 
@@ -278,6 +290,57 @@ _get_secrets_from_keyring (const McpAccountStorage *self,
                 g_warning ("Unsupported value type for %s.%s", account, name);
             }
 
+          if (!tp_strdiff (param, "password"))
+            {
+              /* Empathy 3.0 was meant to migrate passwords from MC to
+               * itself, but it couldn't complete the migration by
+               * deleting the password from MC, because MC had several
+               * bugs that meant deleting passwords didn't work. To atone
+               * for our past sins, detect an incomplete migration and
+               * complete it. */
+              GnomeKeyringResult empathy_ok =
+                GNOME_KEYRING_RESULT_NO_KEYRING_DAEMON;
+              GnomeKeyringAttributeList *empathy_match =
+                gnome_keyring_attribute_list_new ();
+              GList *empathy_items = NULL;
+
+              gnome_keyring_attribute_list_append_string (empathy_match,
+                  "account-id", account);
+              gnome_keyring_attribute_list_append_string (empathy_match,
+                  "param-name", "password");
+
+              empathy_ok = gnome_keyring_find_items_sync (
+                  GNOME_KEYRING_ITEM_GENERIC_SECRET, empathy_match,
+                  &empathy_items);
+
+              if (empathy_ok == GNOME_KEYRING_RESULT_OK &&
+                  empathy_items != NULL)
+                {
+                  KeyringSetData *ksd = g_slice_new0 (KeyringSetData);
+
+                  DEBUG ("An Empathy 3.0 password migration wasn't finished "
+                      "due to fd.o #42088. Finishing it now by deleting the "
+                      "password for %s", account);
+
+                  ksd->account = g_strdup (account);
+                  ksd->name = g_strdup ("password");
+                  ksd->set = FALSE;
+
+                  gnome_keyring_delete_password (&keyring_schema,
+                      _keyring_set_cb, ksd, NULL,
+                      "account", account,
+                      "param", "password",
+                      NULL);
+                }
+
+              gnome_keyring_found_list_free (empathy_items);
+
+              /* behave as if it had already been deleted, i.e. we never
+               * actually found it... */
+              param = NULL;
+              value = NULL;
+            }
+
           if (param != NULL && value != NULL)
             {
               gchar *key = g_strdup_printf ("param-%s", param);
@@ -411,6 +474,10 @@ _set (const McpAccountStorage *self,
   /* if we have a keyring, secrets are segregated */
   secret = mcp_account_manager_parameter_is_secret (am, account, key);
 
+  /* remove it from both sets, then re-add it to the right one if non-null */
+  g_key_file_remove_key (amd->secrets, account, key, NULL);
+  g_key_file_remove_key (amd->keyfile, account, key, NULL);
+
   if (val != NULL)
     {
       if (secret)
@@ -418,13 +485,6 @@ _set (const McpAccountStorage *self,
       else
         g_key_file_set_value (amd->keyfile, account, key, val);
     }
-  else
-    {
-      if (secret)
-        g_key_file_remove_key (amd->secrets, account, key, NULL);
-      else
-        g_key_file_remove_key (amd->keyfile, account, key, NULL);
-    }
 
   /* if we removed the account before, it now exists again, so... */
   g_hash_table_remove (amd->removed_accounts, account);
@@ -561,8 +621,10 @@ _delete (const McpAccountStorage *self,
           g_key_file_remove_group (amd->keyfile, account, NULL);
           _delete_from_keyring (self, am, account, NULL);
         }
-      else if (mcp_account_manager_parameter_is_secret (am, account, key))
+      else
         {
+          /* always delete from keyring, even if we didn't previously
+           * think it was secret - we might have been wrong */
           _delete_from_keyring (self, am, account, key);
         }
 
