@@ -37,8 +37,6 @@
 
 #include "mcd-channel.h"
 
-#include <glib/gi18n.h>
-
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/gtypes.h>
 #include <telepathy-glib/interfaces.h>
@@ -1418,7 +1416,7 @@ mcd_channel_ready_to_depart_cb (TpChannel *channel,
             channel, -1, a, d->message, d->reason,
             mcd_channel_depart_cb, NULL, NULL, NULL);
 
-        g_array_free (a, TRUE);
+        g_array_unref (a);
         g_free (d->message);
         g_slice_free (DepartData, d);
     }
