@@ -40,8 +40,6 @@
 #include "mcd-channel-priv.h"
 #include "mcd-debug.h"
 
-#include "libmcclient/mc-gtypes.h"
-
 G_DEFINE_TYPE (McdClientProxy, _mcd_client_proxy, TP_TYPE_CLIENT);
 
 enum
@@ -496,7 +494,7 @@ _mcd_client_proxy_set_filters (McdClientProxy *client,
             client_filters = g_list_prepend (client_filters,
                                              new_channel_class);
         else
-            g_hash_table_destroy (new_channel_class);
+            g_hash_table_unref (new_channel_class);
     }
 
     switch (interface)
@@ -618,10 +616,8 @@ _mcd_client_recover_observer (McdClientProxy *self, TpChannel *channel,
     satisfied_requests = g_ptr_array_new ();
     observer_info = g_hash_table_new (g_str_hash, g_str_equal);
     tp_asv_set_boolean (observer_info, "recovering", TRUE);
-    /* FIXME: use TP_HASH_TYPE_OBJECT_IMMUTABLE_PROPERTIES_MAP when
-     * available */
     tp_asv_set_boxed (observer_info, "request-properties",
-        MC_HASH_TYPE_OBJECT_IMMUTABLE_PROPERTIES_MAP,
+        TP_HASH_TYPE_OBJECT_IMMUTABLE_PROPERTIES_MAP,
         g_hash_table_new (NULL, NULL));
 
     channels_array = _mcd_tp_channel_details_build_from_tp_chan (channel);
@@ -638,8 +634,8 @@ _mcd_client_recover_observer (McdClientProxy *self, TpChannel *channel,
         NULL, NULL, NULL, NULL);
 
     _mcd_tp_channel_details_free (channels_array);
-    g_ptr_array_free (satisfied_requests, TRUE);
-    g_hash_table_destroy (observer_info);
+    g_ptr_array_unref (satisfied_requests);
+    g_hash_table_unref (observer_info);
 }
 
 static void
@@ -1326,6 +1322,7 @@ _mcd_client_proxy_set_active (McdClientProxy *self,
                               const gchar *unique_name)
 {
     g_return_if_fail (MCD_IS_CLIENT_PROXY (self));
+    g_return_if_fail (unique_name != NULL);
 
     g_free (self->priv->unique_name);
     self->priv->unique_name = g_strdup (unique_name);
@@ -1370,7 +1367,7 @@ mcd_client_proxy_free_client_filters (GList **client_filters)
 
     if (*client_filters != NULL)
     {
-        g_list_foreach (*client_filters, (GFunc) g_hash_table_destroy, NULL);
+        g_list_foreach (*client_filters, (GFunc) g_hash_table_unref, NULL);
         g_list_free (*client_filters);
         *client_filters = NULL;
     }
@@ -1789,6 +1786,6 @@ _mcd_client_proxy_handle_channels (McdClientProxy *self,
         callback, user_data, destroy, weak_object);
 
     _mcd_tp_channel_details_free (channel_details);
-    g_ptr_array_free (requests_satisfied, TRUE);
+    g_ptr_array_unref (requests_satisfied);
     g_hash_table_unref (handler_info);
 }
