@@ -37,7 +37,6 @@
 #include "plugin-loader.h"
 #include "plugin-request.h"
 #include "_gen/interfaces.h"
-#include "_gen/svc-request.h"
 
 enum {
     PROP_0,
@@ -106,7 +105,7 @@ G_DEFINE_TYPE_WITH_CODE (McdRequest, _mcd_request, G_TYPE_OBJECT,
     G_IMPLEMENT_INTERFACE (TP_TYPE_SVC_DBUS_PROPERTIES,
                            tp_dbus_properties_mixin_iface_init))
 
-#define REQUEST_OBJ_BASE "/com/nokia/MissionControl/requests/r"
+#define REQUEST_OBJ_BASE "/org/freedesktop/Telepathy/ChannelDispatcher/Request"
 
 static guint last_req_id = 1;
 
